@@ -1,5 +1,4 @@
 library(corncob)
-library(phyloseq)
 context("Test bbdml")
 
 set.seed(1)
@@ -29,14 +28,34 @@ test_that("overspecified model fails", {
                      inits = rbind(c(1,1,1,1), c(2,2,2,2))))
 })
 
-out_bfgs_inits_num <- bbdml(formula = cbind(W, M - W) ~ X1,
-             phi.formula = ~ X1,
-             data = test_data,
-             link = "logit",
-             phi.link = "logit",
-             method = "BFGS",
-             numerical = TRUE,
-             inits = rbind(c(1,1,1,1), c(2,2,2,2)))
+# check that either an error about needing `optimx` appears, or model is able to be fit
+optimx_install <- try(find.package("optimx"), silent = TRUE)
+if (!(inherits(optimx_install, "try-error"))) {
+  out_bfgs_inits_num <- bbdml(formula = cbind(W, M - W) ~ X1,
+                              phi.formula = ~ X1,
+                              data = test_data,
+                              link = "logit",
+                              phi.link = "logit",
+                              method = "BFGS",
+                              numerical = TRUE,
+                              inits = rbind(c(1,1,1,1), c(2,2,2,2)))
+}
+
+test_that("bbdml with 'BFGS' optimization works", {
+  if (!(inherits(optimx_install, "try-error"))) {
+    expect_is(out_bfgs_inits_num, "bbdml")
+  } else {
+    expect_error(bbdml(formula = cbind(W, M - W) ~ X1,
+                       phi.formula = ~ X1,
+                       data = test_data,
+                       link = "logit",
+                       phi.link = "logit",
+                       method = "BFGS",
+                       numerical = TRUE,
+                       inits = rbind(c(1,1,1,1), c(2,2,2,2))),
+                 "If you would like to use the 'BFGS' method, please install the `optimx` package from CRAN.")
+  }
+})
 
 out_trust <- bbdml(formula = cbind(W, M - W) ~ X1,
                    phi.formula = ~ X1,
@@ -53,12 +72,12 @@ out_bad_init <- suppressWarnings(bbdml(formula = cbind(W, M - W) ~ X1,
                    phi.link = "logit",
                    method = "trust",
                    inits = cbind(1,-1000,1,1000)))
-test_that("bbdml with BFGS, inits, and numerical works", {
-  expect_is(out_bfgs_inits_num, "bbdml")
+test_that("bbdml with BFGS and numerical works", {
   expect_is(out_trust, "bbdml")
   expect_is(out_bad_init, "bbdml")
 })
 
+
 test_that("bad init gives warning", {
   expect_warning(bbdml(formula = cbind(W, M - W) ~ X1,
                        phi.formula = ~ X1,
@@ -71,11 +90,11 @@ test_that("bad init gives warning", {
 
 test_that("checking for perfectly discriminant", {
   expect_warning(tmp <- bbdml(formula = cbind(W, M - W) ~ X1,
-                       phi.formula = ~ X1,
-                       data = test_data_bad,
-                       link = "logit",
-                       phi.link = "logit",
-                       nstart = 1))
+                              phi.formula = ~ X1,
+                              data = test_data_bad,
+                              link = "logit",
+                              phi.link = "logit",
+                              nstart = 1))
   expect_output(expect_warning(print(tmp)))
   expect_output(expect_warning(print(summary(tmp))))
   expect_true(tmp$sep_da) # confirm separation detected
@@ -108,15 +127,19 @@ test_that("checking for perfectly discriminant", {
                        nstart = 1))
 })
 
-data(soil_phylo)
-soil <- phyloseq::subset_samples(soil_phylo, DayAmdmt %in% c(11,21))
+test_that("bbdml returns different model-based and robust standard errors", {
 
-out_phylo <- bbdml(formula = OTU.4 ~ 1,
-             phi.formula = ~ 1,
-             data = soil)
+  model_based <- coef(summary(bbdml(formula = cbind(W, M - W) ~ X1,
+                                    phi.formula = ~ X1,
+                                    data = test_data,
+                                    robust=FALSE)))
+  the_robust <- coef(summary(bbdml(formula = cbind(W, M - W) ~ X1,
+                                   phi.formula = ~ X1,
+                                   data = test_data,
+                                   robust=TRUE)))
 
+  expect_true(sum(abs(model_based[, "Std. Error"] - the_robust[, "Std. Error"])) > 0.1)
+  expect_equal(unname(model_based[, "Estimate"] - the_robust[, "Estimate"]),
+               expected=(rep(0, 4)))
 
-test_that("bbdml works with phyloseq object", {
-  expect_is(out_phylo, "bbdml")
 })
-
